@@ -4,7 +4,11 @@ module Main where
 
 import Debian.Debianize.Optparse(_flags, parseProgramArguments)
 import Control.Lens
+#if MIN_VERSION_Diff(1,0,0)
+import Data.Algorithm.DiffContext (getContextDiff, prettyContextDiff, unnumber)
+#else
 import Data.Algorithm.DiffContext (getContextDiff, prettyContextDiff)
+#endif
 import Data.Bool (bool)
 import Data.Function (on)
 import Data.List (sortBy)
@@ -418,7 +422,7 @@ test4 label =
              (A.debInfo . D.missingDependencies) %= Set.insert (BinPkgName "libghc-clckwrks-theme-clckwrks-doc")
              (A.debInfo . D.sourceFormat) .= Native3
              (A.debInfo . D.control . S.homepage) .= Just "http://www.clckwrks.com/"
-             newDebianization' (Just 9) (Just (StandardsVersion 3 9 6 Nothing))
+             newDebianization' (Just 13) (Just (StandardsVersion 3 9 6 Nothing))
 {-
       customize log = modifyM (lift . customize' log)
       customize' :: Maybe ChangeLog -> CabalInfo -> IO CabalInfo
@@ -439,7 +443,7 @@ test4 label =
       serverNames = map BinPkgName ["clckwrks-dot-com-production"] -- , "clckwrks-dot-com-staging", "clckwrks-dot-com-development"]
       -- Insert a line just above the debhelper.mk include
       fixRules =
-          (debInfo . D.rulesSettings) %= (++ ["DEB_SETUP_GHC_CONFIGURE_ARGS = -fbackups"])
+          (debInfo . D.rulesSettings) %= (++ ["export DEB_SETUP_GHC_CONFIGURE_ARGS = -fbackups"])
 {-
           mapAtoms f deb
           where
@@ -447,7 +451,7 @@ test4 label =
             f Source (DebRulesHead t) =
                 singleton (Source, DebRulesHead (T.unlines $ concat $
                                                  map (\ line -> if line == "include /usr/share/cdbs/1/rules/debhelper.mk"
-                                                                then ["DEB_SETUP_GHC_CONFIGURE_ARGS = -fbackups", "", line] :: [T.Text]
+                                                                then ["export DEB_SETUP_GHC_CONFIGURE_ARGS = -fbackups", "", line] :: [T.Text]
                                                                 else [line] :: [T.Text]) (T.lines t)))
             f k a = singleton (k, a)
 -}
@@ -690,7 +694,7 @@ test10 label =
           do (A.debInfo . D.flags . verbosity) .= 1
              (A.debInfo . D.sourceFormat) .= Native3
              (A.debInfo . D.sourcePackageName) .= Just (SrcPkgName "seereason-darcs-backups")
-             (A.debInfo . D.compat) .= Just 9
+             (A.debInfo . D.compat) .= Just 13
              (A.debInfo . D.control . S.standardsVersion) .= Just (StandardsVersion 3 8 1 Nothing)
              (A.debInfo . D.control . S.maintainer) .= parseMaintainer "David Fox <dsf@seereason.com>"
              (A.debInfo . D.binaryDebDescription (BinPkgName "seereason-darcs-backups") . B.relations . B.depends) %= (++ [[Rel (BinPkgName "anacron") Nothing Nothing]])
@@ -734,15 +738,28 @@ diffDebianizations old new =
       prettyChange (Deleted p _) = text "Deleted: " <> pPrint p <> text "\n"
       prettyChange (Created p b) =
           text "Created: " <> pPrint p <> text "\n" <>
+#if MIN_VERSION_Diff(1,0,0)
+          prettyContextDiff (text ("old" </> p)) (text ("new" </> p)) (text . unpack . unnumber)
+                     -- We use split here instead of lines so we can
+                     -- detect whether the file has a final newline
+                     -- character.
+                     (getContextDiff (Just 2) mempty (split (== '\n') b))
+#else
           prettyContextDiff (text ("old" </> p)) (text ("new" </> p)) (text . unpack)
                      -- We use split here instead of lines so we can
                      -- detect whether the file has a final newline
                      -- character.
                      (getContextDiff 2 mempty (split (== '\n') b))
+#endif
       prettyChange (Modified p a b) =
           text "Modified: " <> pPrint p <> text "\n" <>
+#if MIN_VERSION_Diff(1,0,0)
+          prettyContextDiff (text ("old" </> p)) (text ("new" </> p)) (text . unpack . unnumber)
+                     (getContextDiff (Just 2) (split (== '\n') a) (split (== '\n') b))
+#else
           prettyContextDiff (text ("old" </> p)) (text ("new" </> p)) (text . unpack)
                      (getContextDiff 2 (split (== '\n') a) (split (== '\n') b))
+#endif
 
 sortBinaryDebs :: DebianT IO ()
 sortBinaryDebs = (D.control . S.binaryPackages) %= sortBy (compare `on` view B.package)
