@@ -163,6 +163,7 @@ tests = TestList [ TestCase (assertEqual "Bundled1"
                          actual = Set.fromList (map (unPackageName . pkgName) acp)
                          missing (Just "8.0.1") = Set.fromList ["bin-package-db"]
                          missing (Just "8.0.2") = Set.fromList ["bin-package-db"]
+                         missing (Just "8.8.4") = Set.fromList ["bin-package-db", "hoopl"]
                          missing (Just "9.0.2") = Set.fromList ["bin-package-db", "hoopl"]
                          missing (Just "9.4.6") = Set.fromList ["bin-package-db", "hoopl"]
                          missing (Just "9.6.6") = Set.fromList ["bin-package-db", "hoopl"]
@@ -170,6 +171,7 @@ tests = TestList [ TestCase (assertEqual "Bundled1"
                          extra (Just "7.8.4") = Set.fromList ["haskell2010","haskell98","old-locale","old-time"]
                          extra (Just "8.0.1") = Set.fromList ["ghc-boot","ghc-boot-th","ghci"]
                          extra (Just "8.0.2") = Set.fromList ["ghc-boot","ghc-boot-th","ghci"]
+                         extra (Just "8.8.4") = Set.fromList ["ghc-boot", "ghc-boot-th", "ghc-compact", "ghc-heap", "ghci", "libiserv", "mtl", "parsec", "stm", "text"]
                          extra (Just "9.0.2") = Set.fromList ["exceptions", "ghc-bignum", "ghc-boot", "ghc-boot-th", "ghc-compact", "ghc-heap", "ghci", "libiserv", "mtl", "parsec", "stm", "text"]
                          extra (Just "9.4.6") = Set.fromList ["exceptions", "ghc-bignum", "ghc-boot", "ghc-boot-th", "ghc-compact", "ghc-heap", "ghci", "libiserv", "mtl", "parsec", "stm", "text"]
                          extra (Just "9.6.6") = Set.fromList ["Cabal-syntax","exceptions","ghc-bignum","ghc-boot","ghc-boot-th","ghc-compact","ghc-heap","ghci","libiserv","mtl","parsec","rts","stm","system-cxx-std-lib","text"]
