@@ -23,7 +23,7 @@ import Debian.Debianize.Monad (DebianT)
 import Debian.Debianize.Prelude (escapeDebianWildcards, showDeps')
 import qualified Debian.Debianize.BinaryDebDescription as B (architecture, BinaryDebDescription, binaryPriority, multiArch, binarySection, breaks, builtUsing, conflicts, depends, description, essential, package, PackageRelations, preDepends, provides, recommends, relations, replaces, suggests)
 import Debian.Debianize.CopyrightDescription (CopyrightDescription)
-import qualified Debian.Debianize.SourceDebDescription as S (binaryPackages, buildConflicts, buildConflictsIndep, buildDepends, buildDependsIndep, dmUploadAllowed, homepage, maintainer, priority, rulesRequiresRoot, section, source, SourceDebDescription, standardsVersion, uploaders, vcsFields, VersionControlSpec(VCSArch, VCSBrowser, VCSBzr, VCSCvs, VCSDarcs, VCSGit, VCSHg, VCSMtn, VCSSvn), xDescription, XField(XField), XFieldDest(B, C, S), xFields)
+import qualified Debian.Debianize.SourceDebDescription as S (binaryPackages, buildConflicts, buildConflictsIndep, buildDepends, buildDependsIndep, dmUploadAllowed, homepage, maintainer, priority, rulesRequiresRoot, section, source, SourceDebDescription, standardsVersion, uploaders, vcsFields, VersionControlSpec(VCSArch, VCSBrowser, VCSBzr, VCSCvs, VCSDarcs, VCSGit, VCSHg, VCSMtn, VCSSvn), sourceDescription, XField(XField), XFieldDest(B, C, S), xFields)
 import Debian.Policy (maintainerOfLastResort)
 import Debian.Pretty (PP(..), ppShow, prettyText, ppText, ppPrint)
 import Debian.Relation (BinPkgName(BinPkgName), Relations)
@@ -52,7 +52,6 @@ debianizationFileMap =
        tell =<< control
        tell =<< changelog
        tell =<< rules
-       tell =<< compat
        tell =<< copyright
        tell =<< sourceFormatFiles
        tell =<< watchFile
@@ -158,11 +157,6 @@ control =
     do d <- lift $ use D.control
        return [("debian/control", prettyText (controlFile d))]
 
-compat :: (Monad m) => FilesT m [(FilePath, Text)]
-compat =
-    do t <- lift $ use D.compat
-       return [("debian/compat", pack (show (fromMaybe (error "Missing DebCompat atom - is debhelper installed?") $ t) <> "\n"))]
-
 copyright :: (Monad m) => FilesT m [(FilePath, Text)]
 copyright =
     do copyrt <- lift $ use (D.copyright)
@@ -191,7 +185,7 @@ controlFile src =
             mField "Homepage" (view S.homepage src) ++
             List.map vcsField (Set.toList (view S.vcsFields src)) ++
             List.map xField (Set.toList (view S.xFields src)) ++
-            mField "X-Description" (view S.xDescription src)) :
+            mField "Description" (view S.sourceDescription src)) :
            List.map binary (view S.binaryPackages src))
     }
     where
